@@ -40,7 +40,6 @@
 #include <unistd.h>
 
 #include "battstat.h"
-#include "battstat-hal.h"
 #include "battstat-upower.h"
 
 #define ERR_ACPID _("Can't access ACPI events in /var/run/acpid.socket! "    \
@@ -62,11 +61,12 @@
                            "the ACPI subsystem.  Check to make sure the "   \
                            "ACPI subsystem is properly loaded.")
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 static const char *apm_readinfo (BatteryStatus *status);
 static int pm_initialised;
-#ifdef HAVE_HAL
-static int using_hal;
-#endif
 #ifdef HAVE_UPOWER
 static int using_upower;
 #endif
@@ -175,7 +175,6 @@ apm_readinfo (BatteryStatus *status)
 }
 
 #undef __linux__
-#undef HAVE_HAL
 
 #elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 
@@ -240,7 +239,11 @@ apm_readinfo (BatteryStatus *status)
 #elif defined(__NetBSD__) || defined(__OpenBSD__)
 
 #include <sys/param.h>
+#if defined(__NetBSD__)
+#include <dev/apm/apmio.h>
+#else /* __OpenBSD__ */
 #include <machine/apmvar.h>
+#endif
 
 #define APMDEVICE "/dev/apm"
 
@@ -250,7 +253,11 @@ apm_readinfo (BatteryStatus *status)
   /* Code for OpenBSD by Joe Ammond <jra@twinight.org>. Using the same
      procedure as for FreeBSD.
   */
+#if defined(__NetBSD__)
+  struct apm_power_info apminfo;
+#else /* __OpenBSD__ */
   struct apm_info apminfo;
+#endif
   int fd;
 
 #if defined(__NetBSD__)
@@ -402,14 +409,6 @@ power_management_getinfo( BatteryStatus *status )
     }
   #endif
   
-  #ifdef HAVE_HAL
-    if( using_hal )
-    {
-      battstat_hal_get_battery_info( status );
-      return NULL;
-    }
-  #endif
-
   retval = apm_readinfo( status );
 
   if(status->percent == -1) {
@@ -440,10 +439,9 @@ power_management_getinfo( BatteryStatus *status )
  * the problem might be.  This error message is not to be freed.
  */
 const char *
-power_management_initialise (int no_hal, void (*callback) (void))
+power_management_initialise (void (*callback) (void))
 {
   char *err;
-  err = g_strdup( ":(" );
 #ifdef __linux__
   struct stat statbuf;
 #endif
@@ -462,22 +460,6 @@ power_management_initialise (int no_hal, void (*callback) (void))
     g_free( err );
 #endif
     
-#ifdef HAVE_HAL
-  if(! no_hal ) {
-    err = battstat_hal_initialise (callback);
-    
-    if( err == NULL) /* HAL is up */
-    {
-      pm_initialised = 1;
-      using_hal = TRUE;
-      return NULL;
-    }
-  }
-    
-    /* fallback to legacy methods */
-    g_free( err );
-#endif
-
 #ifdef __linux__
 
   if (acpi_linux_init(&acpiinfo)) {
@@ -532,15 +514,6 @@ power_management_cleanup( void )
   }
 #endif
 
-#ifdef HAVE_HAL
-  if( using_hal )
-  {
-    battstat_hal_cleanup();
-    pm_initialised = 1;
-    return;
-  }
-#endif
-
 #ifdef __linux__
   if (using_acpi)
   {
@@ -568,12 +541,3 @@ power_management_using_upower( void)
 #endif
 }
 
-int
-power_management_using_hal( void )
-{
-#ifdef HAVE_HAL
-  return using_hal;
-#else
-  return 0;
-#endif
-}
