@@ -9,10 +9,12 @@
 #ifdef HAVE_GUCHARMAP
 #include <gucharmap/gucharmap.h>
 #endif
+#include <libmate-desktop/mate-aboutdialog.h>
 #include "charpick.h"
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-#define GTK_OBJECT(x) G_OBJECT(x)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
 #endif
 
 /* The comment for each char list has the html entity names of the chars */
@@ -317,6 +319,20 @@ populate_menu (charpick_data *curr_data)
 		list = g_list_next (list);
 	}
 	build_table(curr_data);
+	
+#if GTK_CHECK_VERSION (3, 0, 0)
+	/*Set up custom theme and transparency support*/
+	GtkWidget *toplevel = gtk_widget_get_toplevel (menu);
+	/* Fix any failures of compiz/other wm's to communicate with gtk for transparency */
+	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
+	GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
+	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual);
+	/* Set menu and it's toplevel window to follow panel theme */
+	GtkStyleContext *context;
+	context = gtk_widget_get_style_context (GTK_WIDGET(toplevel));
+	gtk_style_context_add_class(context,"gnome-panel-menu-bar");
+	gtk_style_context_add_class(context,"mate-panel-menu-bar");
+#endif
 }
 
 static void
@@ -326,8 +342,12 @@ get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 	GtkRequisition  reqmenu;
 	gint tempx, tempy, width, height;
 	gint screen_width, screen_height;
-	
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+        gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &reqmenu);
+#else
 	gtk_widget_size_request (GTK_WIDGET (menu), &reqmenu);
+#endif
 	gdk_window_get_origin (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), &tempx, &tempy);
 	gdk_window_get_geometry (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), NULL, NULL,
 				 &width, &height
@@ -376,6 +396,29 @@ chooser_button_clicked (GtkButton *button, charpick_data *curr_data)
 
 static inline void force_no_focus_padding (GtkWidget *widget)
 {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gboolean        first_time = TRUE;
+	GtkCssProvider *provider;
+
+	if (first_time) {
+		provider = gtk_css_provider_new ();
+
+		gtk_css_provider_load_from_data (provider,
+		                                 "#charpick-applet-button {\n"
+		                                 "-GtkWidget-focus-line-width: 0px;\n"
+		                                 "-GtkWidget-focus-padding: 0px;\n"
+		                                 "}",
+		                                 -1,
+		                                 NULL);
+		gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+		                                GTK_STYLE_PROVIDER (provider),
+		                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+		g_object_unref (provider);
+
+		first_time = FALSE;
+	}
+#else
   gboolean first_time=TRUE;
 
   if (first_time) {
@@ -390,6 +433,7 @@ static inline void force_no_focus_padding (GtkWidget *widget)
 			 "\n");
     first_time = FALSE;
   }
+#endif
 
   gtk_widget_set_name (widget, "charpick-applet-button");
 }
@@ -486,18 +530,22 @@ build_table(charpick_data *p_curr_data)
     force_no_focus_padding (toggle_button[i]);
     gtk_widget_set_tooltip_text (toggle_button[i], name);
     g_free (name);
-                      
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_widget_get_preferred_size (toggle_button[i], NULL, &req);
+#else
     gtk_widget_size_request (toggle_button[i], &req);
+#endif
     
     max_width = MAX (max_width, req.width);
     max_height = MAX (max_height, req.height-2);
   
     g_object_set_data (G_OBJECT (toggle_button[i]), "unichar", 
 				GINT_TO_POINTER(g_utf8_get_char (label)));
-    g_signal_connect (GTK_OBJECT (toggle_button[i]), "toggled",
+    g_signal_connect (G_OBJECT (toggle_button[i]), "toggled",
 		      G_CALLBACK (toggle_button_toggled_cb),
                         p_curr_data);
-    g_signal_connect (GTK_OBJECT (toggle_button[i]), "button_press_event", 
+    g_signal_connect (G_OBJECT (toggle_button[i]), "button_press_event", 
                       G_CALLBACK (button_press_hack), p_curr_data->applet);
   }
   
@@ -516,6 +564,9 @@ build_table(charpick_data *p_curr_data)
   for (i=0; i < size_ratio; i++) {
   	if (!p_curr_data->panel_vertical) row_box[i] = gtk_hbox_new (TRUE, 0);
   	else row_box[i] = gtk_vbox_new (TRUE, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_box_set_homogeneous (GTK_BOX (button_box), TRUE);
+#endif
   	gtk_box_pack_start (GTK_BOX (button_box), row_box[i], TRUE, TRUE, 0);
   }
   
@@ -588,7 +639,7 @@ about (GtkAction     *action,
 	  NULL
   };
 
-  gtk_show_about_dialog (NULL,
+  mate_show_about_dialog (NULL,
 	"version",	VERSION,
 	"copyright",	"\xC2\xA9 1998, 2004-2005 GNOME Applets Maintainers "
 			"and others",
@@ -773,10 +824,10 @@ charpicker_applet_fill (MatePanelApplet *applet)
 			    GDK_SELECTION_CLIPBOARD,
                             utf8_atom,
 			    0);
-  g_signal_connect (GTK_OBJECT (curr_data->applet), "selection_get",
+  g_signal_connect (G_OBJECT (curr_data->applet), "selection_get",
 		      G_CALLBACK (charpick_selection_handler),
 		      curr_data);
-  g_signal_connect (GTK_OBJECT (curr_data->applet), "selection_clear_event",
+  g_signal_connect (G_OBJECT (curr_data->applet), "selection_clear_event",
 		      G_CALLBACK (selection_clear_cb),
 		      curr_data);
  
@@ -813,9 +864,9 @@ charpicker_applet_fill (MatePanelApplet *applet)
   }
   g_object_unref (action_group);
 
-  register_stock_for_edit ();			             
+  register_stock_for_edit ();
   populate_menu (curr_data);
-  
+
   return TRUE;
 }
 
