@@ -18,6 +18,8 @@
 #include <stdlib.h>
 #include <assert.h>
 
+#include <libmate-desktop/mate-aboutdialog.h>
+
 #define MATEWEATHER_I_KNOW_THIS_IS_UNSTABLE
 
 #include "mateweather.h"
@@ -43,7 +45,7 @@ void mateweather_about_run(MateWeatherApplet* gw_applet)
 		NULL
 	};
 
-	gtk_show_about_dialog(NULL,
+	mate_show_about_dialog(NULL,
 		"version", VERSION,
 		"copyright", _("\xC2\xA9 1999-2005 by S. Papadimitriou and others"),
 		"comments", _("A panel application for monitoring local weather conditions."),
