@@ -27,6 +27,11 @@
 #include "mateweather-pref.h"
 #include "mateweather-dialog.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 struct _MateWeatherDialogPrivate {
 	GtkWidget* cond_location;
 	GtkWidget* cond_update;
