@@ -226,7 +226,7 @@ GetMemory (int Maximum, int data [5], LoadGraph *g)
 void
 GetSwap (int Maximum, int data [2], LoadGraph *g)
 {
-    int used, free;
+    int used;
 
     glibtop_swap swap;
 
@@ -235,11 +235,9 @@ GetSwap (int Maximum, int data [2], LoadGraph *g)
 
     if (swap.total == 0) {
 	used = 0;
-	free = Maximum;
     }
     else {
 	used    = rint (Maximum * (float)swap.used / swap.total);
-	free    = rint (Maximum * (float)swap.free / swap.total);
     }
 
     data [0] = used;
@@ -252,7 +250,7 @@ GetLoadAvg (int Maximum, int data [2], LoadGraph *g)
     const float per_cpu_max_loadavg = 5.0f;
     float max_loadavg;
     float loadavg1;
-    float used, free;
+    float used;
 
     glibtop_loadavg loadavg;
     glibtop_get_loadavg (&loadavg);
@@ -265,7 +263,6 @@ GetLoadAvg (int Maximum, int data [2], LoadGraph *g)
     loadavg1 = MIN(loadavg.loadavg[0], max_loadavg);
 
     used    = loadavg1 / max_loadavg;
-    free    = (max_loadavg - loadavg1) / max_loadavg;
 
     data [0] = rint ((float) Maximum * used);
     data [1] = Maximum - data[0];
@@ -288,21 +285,28 @@ is_net_device_virtual(char *device)
      * /sys/class/net/name-of-dev/ .  This second method is more complex
      * but more reliable.
      */
-    char path[PATH_MAX];
+    gboolean ret = FALSE;
+    char *path = malloc (strlen (device) + strlen ("/sys/class/net//device") + 1);
+
+    if (path == NULL)
+        return FALSE;
 
     /* Check if /sys/class/net/name-of-dev/ exists (may be old linux kernel
      * or not linux at all). */
-    if (sprintf(path, "/sys/class/net/%s", device) < 0)
-        return FALSE;
-    if (access(path, F_OK) != 0)
-        return FALSE; /* unknown */
+    do {
+        if (sprintf(path, "/sys/class/net/%s", device) < 0)
+            break;
+        if (access(path, F_OK) != 0)
+            break; /* unknown */
 
-    if (sprintf(path, "/sys/class/net/%s/device", device) < 0)
-        return FALSE;
-    if (access(path, F_OK) != 0)
-        return TRUE;
+        if (sprintf(path, "/sys/class/net/%s/device", device) < 0)
+            break;
+        if (access(path, F_OK) != 0)
+            ret = TRUE;
+    } while (0);
 
-    return FALSE;
+    free (path);
+    return ret;
 }
 
 void
