@@ -19,14 +19,23 @@
 #include <time.h>
 
 #include <glibtop.h>
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
 
+#include <libmate-desktop/mate-aboutdialog.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-desktop-utils.h>
+#define gdk_spawn_command_line_on_screen mate_gdk_spawn_command_line_on_screen
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 #include "global.h"
 
 static void
@@ -49,7 +58,7 @@ about_cb (GtkAction       *action,
 		NULL
     };
 
-    gtk_show_about_dialog (NULL,
+    mate_show_about_dialog (NULL,
 	"version",	VERSION,
 	"copyright",	"\xC2\xA9 1999-2005 Free Software Foundation "
 			"and others",
@@ -71,7 +80,7 @@ help_cb (GtkAction       *action,
  	GError *error = NULL;
                                                                                 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
-			"ghelp:multiload",
+			"help:mate-multiload",
 			gtk_get_current_event_time (),
 			&error);
 
@@ -92,6 +101,9 @@ start_procman (MultiloadApplet *ma)
 	GError *error = NULL;
 	GDesktopAppInfo *appinfo;
 	gchar *monitor;
+	GdkAppLaunchContext *launch_context;
+	GAppInfo *app_info;
+	GdkScreen *screen;
 
 	g_return_if_fail (ma != NULL);
 
@@ -99,6 +111,7 @@ start_procman (MultiloadApplet *ma)
 	if (monitor == NULL)
 	        monitor = g_strdup ("mate-system-monitor.desktop");
 
+	screen = gtk_widget_get_screen (GTK_WIDGET (ma->applet));
 	appinfo = g_desktop_app_info_new (monitor);
 	if (appinfo) {
 		GdkScreen *screen;
@@ -111,9 +124,18 @@ start_procman (MultiloadApplet *ma)
 		g_object_unref (appinfo);
 	}
 	else {
-	     	gdk_spawn_command_line_on_screen (
-				gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
-				"mate-system-monitor", &error);
+		app_info = g_app_info_create_from_commandline ("mate-system-monitor",
+							      _("Start system-monitor"),
+							      G_APP_INFO_CREATE_NONE,
+							      &error);
+
+		if (!error) {
+			launch_context = gdk_app_launch_context_new ();
+			gdk_app_launch_context_set_screen (launch_context, screen);
+			g_app_info_launch (app_info, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error);
+
+			g_object_unref (launch_context);
+		}
 	}
 	g_free (monitor);
 
@@ -224,12 +246,12 @@ multiload_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MultiloadAp
 	switch (event->keyval) {
 	/* this list of keyvals taken from mixer applet, which seemed to have
 		a good list of keys to use */
-	case GDK_KP_Enter:
-	case GDK_ISO_Enter:
-	case GDK_3270_Enter:
-	case GDK_Return:
-	case GDK_space:
-	case GDK_KP_Space:
+	case GDK_KEY_KP_Enter:
+	case GDK_KEY_ISO_Enter:
+	case GDK_KEY_3270_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_space:
+	case GDK_KEY_KP_Space:
 		/* activate */
 		start_procman (ma);
 		return TRUE;
