@@ -393,7 +393,7 @@ timer_applet_fill (MatePanelApplet* applet_widget)
         notify_init ("timer-applet");
 
     mate_panel_applet_set_flags (applet_widget, MATE_PANEL_APPLET_EXPAND_MINOR);
-    mate_panel_applet_set_background_widget (applet_widget, GTK_WIDGET (applet));
+    mate_panel_applet_set_background_widget (MATE_PANEL_APPLET (applet_widget), GTK_WIDGET (applet_widget));
 
     applet = g_malloc0(sizeof(TimerApplet));
     applet->applet = applet_widget;
